@@ -9,7 +9,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use NetPacket;
 use NetPacket::IP;
 
-our $VERSION = '0.42.0';
+our $VERSION = '0.43.0';
 
 BEGIN {
     @ISA = qw(Exporter NetPacket);
@@ -117,17 +117,12 @@ sub checksum {
     no warnings;
 
     my $packet = pack 'a4a4CCnnnnna*' =>
-    			# fake ip header part
-            $src_ip,     
-	    $dest_ip,
-	    0,
-	    $proto,
-	    		# proper UDP part
-            $self->{src_port}, 
-	    $self->{dest_port}, 
-            $self->{len},
-	    0,
-	    $self->{data};
+
+      # fake ip header part
+      $src_ip, $dest_ip, 0, $proto, $self->{len},
+
+      # proper UDP part
+      $self->{src_port}, $self->{dest_port}, $self->{len}, 0, $self->{data};
 
     $packet .= "\x00" if length($packet) % 2;
 
@@ -174,10 +169,10 @@ instance data.  This method will quite happily decode garbage input.
 It is the responsibility of the programmer to ensure valid packet data
 is passed to this method.
 
-=item C<NetPacket::UDP-E<gt>encode(param =E<gt> value)>
+=item C<NetPacket::UDP-E<gt>encode($ip_obj)>
 
 Return a UDP packet encoded with the instance data specified. Needs parts 
-of the ip header contained in $ip_obj, the IP object, in order to calculate 
+of the IP header contained in $ip_obj, the IP object, in order to calculate 
 the UDP checksum. The length field will also be set automatically.
 
 =back
@@ -237,9 +232,7 @@ none
 
 =item exportable
 
-igmp_strip IGMP_VERSION_RFC998 IGMP_VERSION_RFC1112
-IGMP_MSG_HOST_MQUERY IGMP_MSG_HOST_MREPORT IGMP_IP_NO_HOSTS
-IGMP_IP_ALL_HOSTS IGMP_IP_ALL_ROUTERS
+udp_strip
 
 =item tags
 
@@ -249,19 +242,7 @@ The following tags group together related exportable items.
 
 =item C<:strip>
 
-Import the strip function C<igmp_strip>.
-
-=item C<:versions>
-
-IGMP_VERSION_RFC998 IGMP_VERSION_RFC1112
-
-=item C<:msgtypes>
-
-IGMP_HOST_MQUERY IGMP_HOST_MREPORT
-
-=item C<:group_addrs>
-
-IGMP_IP_NO_HOSTS IGMP_IP_ALL_HOSTS IGMP_IP_ALL_ROUTERS
+Import the strip function C<udp_strip>.
 
 =item C<:ALL>
 
@@ -273,8 +254,8 @@ All the above exportable items.
 
 =head1 EXAMPLE
 
-The following script dumps IGMP the contents of IGMP frames to
-standard output.
+The following example prints the source IP address and port, the
+destination IP address and port, and the UDP packet length:
 
   #!/usr/bin/perl -w
 
